<?php

/**
 * @file
 *  taxonomy_image_views_options.theme.inc
 *  Theme functions for taxonomy_image_views_options.module.
 * @author Christoffer Johansson (Scyther), www.christofferjohansson.se
 */

/**
 * Get the taxonomy image.
 * @param
 *   $tid - the term id
 * @return
 *   Image in HTML.
 */
function theme_taxonomy_image_views_options_formatter_image_plain($tid) {
  $image = taxonomy_image_get_object($tid);
  return $image->img;
}

/**
 * Get the taxonomy image as a link to the taxonomy term.
 * @param
 *   $tid - the term id
 * @return
 *   HTML link.
 */
function theme_taxonomy_image_views_options_formatter_image_link_taxonomy($tid) {
  $image = taxonomy_image_get_object($tid);
  return l($image->img, $image->term, $options = array('html' => TRUE));
}

/**
 * Get the taxonomy image as a link to the image.
 * @param
 *   $tid - the term id
 * @return
 *   HTML link.
 */
function theme_taxonomy_image_views_options_formatter_image_link_image($tid) {
  $image = taxonomy_image_get_object($tid);
  return l($image->img, $image->url, $options = array('html' => TRUE));
}

/**
 * Get the path to the taxonomy image.
 * @param
 *   $tid - the term id
 * @return
 *   The path string.
 */
function theme_taxonomy_image_views_options_formatter_path_to_image($tid) {
  return taxonomy_image_views_options_get_path($tid);
}

/**
 * Get the URL to the taxonomy image.
 * @param
 *   $tid - the term id
 * @return
 *   The URL string.
 */
function theme_taxonomy_image_views_options_formatter_url_to_image($tid) {
  return taxonomy_image_get_url($tid);
}

/**
 * Get the taxonomy image, that have been processed by imagechache.
 * @param
 *   $tid - the term id
 * @param
 *   $preset - the imagecache preset that will be called
 * @return
 *   Image in HTML.
 */
function theme_taxonomy_image_views_options_formatter_imagecache_default($tid, $preset) {
  return theme('imagecache', $preset, taxonomy_image_views_options_get_path($tid));
}

/**
 * Get the taxonomy image, that have been processed by imagechache, as a link to the taxonomy term.
 * @param
 *   $tid - the term id
 * @param
 *   $preset - the imagecache preset that will be called
 * @return
 *   HTML link.
 */
function theme_taxonomy_image_views_options_formatter_imagecache_termlink($tid, $preset) {
  $image = taxonomy_image_get_object($tid);
  return l(theme('imagecache', $preset, taxonomy_image_views_options_get_path($tid)), $image->term, $options = array('html' => TRUE));
}

/**
 * Get the taxonomy image, that have been processed by imagechache, as a link to the image.
 * @param
 *   $tid - the term id
 * @param
 *   $preset - the imagecache preset that will be called
 * @return
 *   HTML link.
 */
function theme_taxonomy_image_views_options_formatter_imagecache_imagelink($tid, $preset) {
  $image = taxonomy_image_get_object($tid);
  return l(theme('imagecache', $preset, taxonomy_image_views_options_get_path($tid)), $image->url, $options = array('html' => TRUE));
}

/**
 * Get the path to the taxonomy image that have been processed by imagechache.
 * @param
 *   $tid - the term id
 * @param
 *   $preset - the imagecache preset that will be called
 * @return
 *   The path string.
 */
function theme_taxonomy_image_views_options_formatter_imagecache_path($tid, $preset) {
  return imagecache_create_path($preset, taxonomy_image_views_options_get_path($tid));
}

/**
 * Get the URL to the taxonomy image that have been processed by imagechache.
 * @param
 *   $tid - the term id
 * @param
 *   $preset - the imagecache preset that will be called
 * @return
 *   The URL string.
 */
function theme_taxonomy_image_views_options_formatter_imagecache_url($tid, $preset) {
  return imagecache_create_url($preset, taxonomy_image_views_options_get_path($tid));
}

/**
 * Show the taxnonmy image in a shadowbox.
 * @param
 *   $tid - the term id
 * @param
 *   $source - the imagecache preset on the image
 * @param
 *   $destination - the imagecache preset on the image that will be open in a shadowbox
 * @return
 *   The URL string.
 */
function theme_taxonomy_image_views_options_formatter_shadowbox($tid, $source, $destination) {
  $term = taxonomy_get_term($tid);
  $filepath = taxonomy_image_views_options_get_path($tid);
  $alt = $title = $term->name;

  $link_attributes = array(
    'rel' => 'shadowbox',
    'title' => $title,
  );
  $options = array(
    'attributes' => $link_attributes,
    'html' => TRUE,
  );


  if ($source == 'original') {
    $image = theme('shadowbox_image', $filepath, $alt, $title);
  }
  else {
    $image = theme('imagecache', $source, $filepath, $alt, $title);
  }

  if ($destination == 'original') {
    $output = l($image, file_create_url($filepath), $options);
  }
  else {
    $output = l($image, shadowbox_imagecache_create_url($destination, $filepath), $options);
  }

  return $output;
}
