<?php

/**
 * @file
 * Views integration for Taxonomy Image Views Options module.
 */

/**
 * Field handler to provide an embedded image.
 *
 * @ingroup views_field_handlers
 */
class views_handler_field_taxonomy_image_views_options extends views_handler_field {
  /**
   * Define options available for this field.
   */
  function option_definition() {
    $options = parent::option_definition();
    $options['display_format'] = array('default' => 'image_plain');
    return $options;
  }

  /**
   * Build option configuration form.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $presets['default'] = array(
      'image_plain' => t('Image'),
      'image_link_taxonomy' => t('Image linked to term page'),
      'image_link_image' => t('Image linked to image'),
      'path_to_image' => t('Path to image'),
      'url_to_image' => t('URL to image'),
    );

    if (module_exists('imagecache')) {
      foreach (imagecache_presets() as $preset) {
        $presets['imagecache']['imagecache_' . $preset['presetname'] . '_default'] = t('@preset image', array('@preset' => $preset['presetname']));
        $presets['imagecache']['imagecache_' . $preset['presetname'] . '_termlink'] = t('@preset image linked to term page', array('@preset' => $preset['presetname']));
        $presets['imagecache']['imagecache_' . $preset['presetname'] . '_imagelink'] = t('@preset image linked to image', array('@preset' => $preset['presetname']));
        $presets['imagecache']['imagecache_' . $preset['presetname'] . '_path'] = t('@preset file path', array('@preset' => $preset['presetname']));
        $presets['imagecache']['imagecache_' . $preset['presetname'] . '_url'] = t('@preset URL', array('@preset' => $preset['presetname']));

        if (module_exists('shadowbox')) {
          $presets['shadowbox']['shadowbox___original___' . $preset['presetname']] = t('SB: original to @preset', array('@preset' => $preset['presetname']));
          $presets['shadowbox']['shadowbox___' . $preset['presetname'] . '___original'] = t('SB: @preset to original', array('@preset' => $preset['presetname']));

          foreach (imagecache_presets() as $preset_alt) {
            if ($preset['presetname'] != $preset_alt['presetname']) {
              $presets['shadowbox']['shadowbox___' . $preset['presetname'] .'___' . $preset_alt['presetname']] = t('SB: @preset to @preset_alt', array('@preset' => $preset['presetname'], '@preset_alt' => $preset_alt['presetname']));
            }
          }
        }
      }
    }

    $display_options = array();
    foreach ($presets as $array) {
      $display_options += $array;
    }

    $form['display_format'] = array(
      '#type' => 'select',
      '#title' => t('Display'),
      '#options' => $display_options,
      '#default_value' => $this->options['display_format'],
    );
  }

  /**
   * Render field output to the browser.
   */
  function render($values) {
    $display_format = $this->options['display_format'];
    $tid = $values->{$this->field_alias};

    if (!$tid) {
      return;
    }

    if (drupal_substr($display_format, 0, 11) == 'imagecache_') {
      $preset = drupal_substr($display_format, 11);
      $preset = drupal_substr($preset, 0, strrpos($preset, '_'));

      return theme('taxonomy_image_views_options_formatter_' . $display_format, $tid, $preset);
    }
    elseif (drupal_substr($display_format, 0, 12) == 'shadowbox___') {
      list($theme, $source, $destination) = explode('___', $display_format, 3);
      return theme('taxonomy_image_views_options_formatter_shadowbox', $tid, $source, $destination);
    }
    else {
      return theme('taxonomy_image_views_options_formatter_' . $display_format, $tid);
    }
  }
}
